@@ -188,7 +188,8 @@ def main() -> None:
     """Main entry point"""
 
     loop = asyncio.get_event_loop()
-    loop.run_until_complete(asyncio.wait([async_main()]))
+    task = loop.create_task(async_main())
+    loop.run_until_complete(task)
 
 
 if __name__ == "__main__":
