@@ -5,6 +5,7 @@ from typing import Text, Optional, Any
 import argparse
 import asyncio
 import greenstalk
+import html
 import json
 import logging
 import os
@@ -106,14 +107,20 @@ class Server:
                 self.client.delete(job)  # type: ignore
                 continue
 
-            with open(meta_data['filename'], 'rb') as buffer:
-                data = parser.from_buffer(buffer)
+            with open(meta_data['filename'], 'rb') as fh:
+                content = fh.read()
+                if meta_data['filename'].endswith(".html"):
+                    content = html.unescape(content.decode("utf8")).encode("utf8")
+                data = parser.from_buffer(content)
                 data.update(meta_data)
 
             self.client.delete(job)  # type: ignore
             logging.info("Worker [%s] waiting to post result.", worker_id)
-            self.client.put(gzip.compress(json.dumps({**data, **meta_data}).encode('utf8')))  # type: ignore
-            logging.info("Worker [%s] job done.", worker_id)
+            try:
+                self.client.put(gzip.compress(json.dumps({**data, **meta_data}).encode('utf8')))  # type: ignore
+                logging.info("Worker [%s] job done.", worker_id)
+            except greenstalk.JobTooBigError:
+                logging.error("Job to big: %s.", meta_data['filename'])
 
     async def _start(self, n: int) -> None:
         """Start the server, create n number of workers and wait for data on the queue"""
